class JobNotFound(Exception):
  pass

class GroupNotFound(Exception):
  pass

class UpgradeFail(Exception):
  pass

class TykServiceNotFound(Exception):
  pass

class TykReloadFailed(Exception):
  pass
class JobTemplateIsNotFound(Exception):
  pass
